
# Slot: object


the gene or gene product that is affected by the chemical.

URI: [biolink:chemical_to_gene_association_object](https://w3id.org/biolink/vocab/chemical_to_gene_association_object)


## Domain and Range

[ChemicalToGeneAssociation](ChemicalToGeneAssociation.md) &#8594;  <sub>1..1</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [ChemicalToGeneAssociation](ChemicalToGeneAssociation.md)
